==> igniteui-react-16.16.2.tgz: package/esm5/lib/igr-input.js <==
import { __extends } from "tslib";
import * as React from 'react';
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { InputDir_$type } from "./InputDir";
import { InputType_$type } from "./InputType";
import { InputInputmode_$type } from "./InputInputmode";
import { IgrComponentValueChangedEventArgs } from "./igr-component-value-changed-event-args";
import { IgrInputBase } from "./igr-input-base";
import { Input } from "./Input";
import { IgcInputComponent, defineComponents } from "igniteui-webcomponents";
import { ensureEnum, ensureBool } from "igniteui-react-core";
/**

*/
var IgrInput = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrInput, _super);
    function IgrInput(props) {
        var _this = _super.call(this, props) || this;
        _this._change = null;
        _this._change_wrapped = null;
        _this._getMainRef = _this._getMainRef.bind(_this);
        defineComponents(IgcInputComponent);
        return _this;
    }
    IgrInput.prototype.createImplementation = function () {
        return new Input();
    };
    Object.defineProperty(IgrInput.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrInput.prototype.componentDidMount = function () {
        this.i.nativeElement = this._elRef;
        _super.prototype.componentDidMount.call(this);
    };
    IgrInput.prototype.render = function () {
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        var div = React.createElement("igc-input", {
            ref: this._getMainRef,
            className: this.props.className,
            style: this.props.style,
            children: children
        });
        return div;
    };
    IgrInput.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    Object.defineProperty(IgrInput.prototype, "value", {
        get: function () {
            return this.i.al;
        },
        set: function (v) {
            this.i.al = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrInput.prototype, "dir", {
        /**
         * The direction attribute of the control.
        */
        get: function () {
            return this.i.z;
        },
        set: function (v) {
            this.i.z = ensureEnum(InputDir_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrInput.prototype, "displayType", {
        /**
         * The type attribute of the control.
        */
        get: function () {
            return this.i.ab;
        },
        set: function (v) {
            this.i.ab = ensureEnum(InputType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrInput.prototype, "inputmode", {
        /**
         * The input mode attribute of the control.
        */
        get: function () {
            return this.i.aa;
        },
        set: function (v) {
            this.i.aa = ensureEnum(InputInputmode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrInput.prototype, "pattern", {
        /**
         * The pattern attribute of the control.
        */
        get: function () {
            return this.i.ak;
        },
        set: function (v) {
            this.i.ak = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrInput.prototype, "invalid", {
        /**
         * Controls the validity of the control.
        */
        get: function () {
            return this.i.ad;
        },
        set: function (v) {
            this.i.ad = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrInput.prototype, "minlength", {
        /**
         * The minlength attribute of the control.
        */
        get: function () {
            return this.i.af;
        },
        set: function (v) {
            this.i.af = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrInput.prototype, "maxlength", {
        /**
         * The maxlength attribute of the control.
        */
        get: function () {
            return this.i.ae;
        },
        set: function (v) {
            this.i.ae = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrInput.prototype, "min", {
        /**
         * The min attribute of the control.
        */
        get: function () {
            return this.i.aj;
        },
        set: function (v) {
            this.i.aj = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrInput.prototype, "max", {
        /**
         * The max attribute of the control.
        */
        get: function () {
            return this.i.ai;
        },
        set: function (v) {
            this.i.ai = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrInput.prototype, "step", {
        /**
         * The step attribute of the control.
        */
        get: function () {
            return this.i.ag;
        },
        set: function (v) {
            this.i.ag = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrInput.prototype, "autofocus", {
        /**
         * The autofocus attribute of the control.
        */
        get: function () {
            return this.i.ac;
        },
        set: function (v) {
            this.i.ac = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrInput.prototype, "autocomplete", {
        /**
         * The autocomplete attribute of the control.
        */
        get: function () {
            return this.i.ah;
        },
        set: function (v) {
            this.i.ah = v;
        },
        enumerable: false,
        configurable: true
    });
    /**
     * Checks for validity of the control and shows the browser message if it's invalid.
    
    */
    IgrInput.prototype.reportValidity = function () {
        this.i.an();
    };
    /**
     * Sets a custom validation message for the control.
     * As long as `message` is not empty, the control is considered invalid.
    
    */
    IgrInput.prototype.setCustomValidity = function (message) {
        this.i.ap(message);
    };
    /**
     * Selects all text within the input.
    
    */
    IgrInput.prototype.select = function () {
        this.i.ao();
    };
    /**
     * Increments the numeric value of the input by one or more steps.
    
    */
    IgrInput.prototype.stepUp = function (n) {
        this.i.ar(n);
    };
    /**
     * Decrements the numeric value of the input by one or more steps.
    
    */
    IgrInput.prototype.stepDown = function (n) {
        this.i.aq(n);
    };
    Object.defineProperty(IgrInput.prototype, "change", {
        get: function () {
            return this._change;
        },
        set: function (ev) {
            var _this = this;
            if (this._change_wrapped !== null) {
                this.i.change = delegateRemove(this.i.change, this._change_wrapped);
                this._change_wrapped = null;
                this._change = null;
            }
            this._change = ev;
            this._change_wrapped = function (o, e) {
                var outerArgs = new IgrComponentValueChangedEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeChange) {
                    _this.beforeChange(_this, outerArgs);
                }
                if (_this._change) {
                    _this._change(_this, outerArgs);
                }
            };
            this.i.change = delegateCombine(this.i.change, this._change_wrapped);
            if (this.i.changeChanged) {
                this.i.changeChanged();
            }
            ;
        },
        enumerable: false,
        configurable: true
    });
    return IgrInput;
}(IgrInputBase));
export { IgrInput };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/igr-input.js <==
import { __extends } from "tslib";
import * as React from 'react';
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { InputType_$type } from "./InputType";
import { InputInputmode_$type } from "./InputInputmode";
import { IgrComponentValueChangedEventArgs } from "./igr-component-value-changed-event-args";
import { IgrInputBase } from "./igr-input-base";
import { Input } from "./Input";
import { IgcInputComponent, defineComponents } from "igniteui-webcomponents";
import { ensureEnum, ensureBool } from "igniteui-react-core";
/**

*/
var IgrInput = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrInput, _super);
    function IgrInput(props) {
        var _this = _super.call(this, props) || this;
        _this._change = null;
        _this._change_wrapped = null;
        _this._getMainRef = _this._getMainRef.bind(_this);
        defineComponents(IgcInputComponent);
        return _this;
    }
    IgrInput.prototype.createImplementation = function () {
        return new Input();
    };
    Object.defineProperty(IgrInput.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrInput.prototype.componentDidMount = function () {
        this.i.nativeElement = this._elRef;
        _super.prototype.componentDidMount.call(this);
    };
    IgrInput.prototype.render = function () {
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        var style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        var div = React.createElement("igc-input", {
            ref: this._getMainRef,
            className: this.props.className,
            style: style,
            children: children
        });
        return div;
    };
    IgrInput.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    Object.defineProperty(IgrInput.prototype, "value", {
        /**
         * The value of the control.
        */
        get: function () {
            return this.i.am;
        },
        set: function (v) {
            this.i.am = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrInput.prototype, "type", {
        /**
         * The type attribute of the control.
        */
        get: function () {
            return this.i.ab;
        },
        set: function (v) {
            this.i.ab = ensureEnum(InputType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrInput.prototype, "inputmode", {
        /**
         * The input mode attribute of the control.
        */
        get: function () {
            return this.i.aa;
        },
        set: function (v) {
            this.i.aa = ensureEnum(InputInputmode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrInput.prototype, "pattern", {
        /**
         * The pattern attribute of the control.
        */
        get: function () {
            return this.i.al;
        },
        set: function (v) {
            this.i.al = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrInput.prototype, "invalid", {
        /**
         * Controls the validity of the control.
        */
        get: function () {
            return this.i.ad;
        },
        set: function (v) {
            this.i.ad = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrInput.prototype, "minlength", {
        /**
         * The minlength attribute of the control.
        */
        get: function () {
            return this.i.af;
        },
        set: function (v) {
            this.i.af = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrInput.prototype, "maxlength", {
        /**
         * The maxlength attribute of the control.
        */
        get: function () {
            return this.i.ae;
        },
        set: function (v) {
            this.i.ae = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrInput.prototype, "min", {
        /**
         * The min attribute of the control.
        */
        get: function () {
            return this.i.ak;
        },
        set: function (v) {
            this.i.ak = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrInput.prototype, "max", {
        /**
         * The max attribute of the control.
        */
        get: function () {
            return this.i.aj;
        },
        set: function (v) {
            this.i.aj = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrInput.prototype, "step", {
        /**
         * The step attribute of the control.
        */
        get: function () {
            return this.i.ag;
        },
        set: function (v) {
            this.i.ag = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrInput.prototype, "autofocus", {
        /**
         * The autofocus attribute of the control.
        */
        get: function () {
            return this.i.ac;
        },
        set: function (v) {
            this.i.ac = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrInput.prototype, "autocomplete", {
        /**
         * The autocomplete attribute of the control.
        */
        get: function () {
            return this.i.ai;
        },
        set: function (v) {
            this.i.ai = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrInput.prototype, "tabIndex", {
        get: function () {
            return this.i.ah;
        },
        set: function (v) {
            this.i.ah = +v;
        },
        enumerable: false,
        configurable: true
    });
    /**
     * Checks for validity of the control and shows the browser message if it's invalid.
    
    */
    IgrInput.prototype.reportValidity = function () {
        this.i.ap();
    };
    /**
     * Checks for validity of the control and emits the invalid event if it invalid.
    
    */
    IgrInput.prototype.checkValidity = function () {
        this.i.ao();
    };
    /**
     * Sets a custom validation message for the control.
     * As long as `message` is not empty, the control is considered invalid.
    
    */
    IgrInput.prototype.setCustomValidity = function (message) {
        this.i.ar(message);
    };
    /**
     * Selects all text within the input.
    
    */
    IgrInput.prototype.select = function () {
        this.i.aq();
    };
    /**
     * Increments the numeric value of the input by one or more steps.
    
    */
    IgrInput.prototype.stepUp = function (n) {
        this.i.at(n);
    };
    /**
     * Decrements the numeric value of the input by one or more steps.
    
    */
    IgrInput.prototype.stepDown = function (n) {
        this.i.as(n);
    };
    Object.defineProperty(IgrInput.prototype, "change", {
        get: function () {
            return this._change;
        },
        set: function (ev) {
            var _this = this;
            if (this._change_wrapped !== null) {
                this.i.change = delegateRemove(this.i.change, this._change_wrapped);
                this._change_wrapped = null;
                this._change = null;
            }
            this._change = ev;
            this._change_wrapped = function (o, e) {
                var outerArgs = new IgrComponentValueChangedEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeChange) {
                    _this.beforeChange(_this, outerArgs);
                }
                if (_this._change) {
                    _this._change(_this, outerArgs);
                }
            };
            this.i.change = delegateCombine(this.i.change, this._change_wrapped);
            if (this.i.changeChanged) {
                this.i.changeChanged();
            }
            ;
        },
        enumerable: false,
        configurable: true
    });
    return IgrInput;
}(IgrInputBase));
export { IgrInput };
